==> faiadashu-0.1.4.tar.gz: README.md <==
[![style: lint](https://img.shields.io/badge/style-lint-4BC0F5.svg)](https://pub.dev/packages/lint)
[![pub package](https://img.shields.io/pub/v/faiadashu.svg?logo=flutter)](https://pub.dartlang.org/packages/faiadashu)
# *Faiadashu™ FHIRDash* — Widgets for Digital Health

## Mission
Build beautiful healthcare apps fast — use the Flutter™ SDK and follow the HL7® FHIR® standard.

> FHIR® is the registered trademark of HL7 and is used with the permission of HL7. Use of the FHIR trademark does not constitute endorsement of this product by HL7.

## Features
* **A ready-made Widget to fill FHIR® Questionnaires.**
* Formatted and localized output of clinical observations
* Formatted and localized output of dates / times
* Localized output of clinical codings
* Development tree view to introspect clinical and administrative data structures
  
## Gallery
### Filler for FHIR Questionnaires
![Swift walk-through](https://user-images.githubusercontent.com/16414047/113286611-bdd93d00-92ec-11eb-9c7d-fd72dd0b99fe.gif)

**Click link below for extended, narrated video**

[Demo Video on YT](https://youtu.be/k9vEy9Z_L18)

### Display formatted, localized observations
![Screenshot](https://user-images.githubusercontent.com/16414047/112978818-12977f00-9158-11eb-8e1c-6772dcc3270a.png)


### Development overview
[Development Overview](doc/overview.md) - Learn how to use the Faidashu FHIRDash library in your own projects.

### Related projects
[![Pub Version](https://img.shields.io/pub/v/fhir?label=pub.dev&labelColor=333940&logo=dart)](https://pub.dev/packages/fhir)
This is mainly a user interface add-on to the awesome FHIRFLI "fhir" library: https://pub.dev/packages/fhir

### Contributing
Contributions and discussions are welcome! This is currently not well-defined yet. I will soon post an invite link to the awesome FHIR-FLI
Slack channel which is run by some like-minded folks and where I can be frequently found.

### License
The library is licensed under the MIT license. The full license text is here [LICENSE](LICENSE).

### Full list of legal attributions
Due to its nature, this library requires a multitude of third-party content and licenses. It is up to you to examine the
provided information and decide whether you meet the obligations to use this library and/or the contained content.

[Legal Information](doc/disclaimers.md)

**This information is not a substitute for professional legal advice.**

==> faiadashu-0.1.7.tar.gz: README.md <==
[![style: lint](https://img.shields.io/badge/style-lint-4BC0F5.svg)](https://pub.dev/packages/lint)
[![pub package](https://img.shields.io/pub/v/faiadashu.svg?logo=flutter)](https://pub.dartlang.org/packages/faiadashu)
# *Faiadashu™ FHIRDash* — Widgets for Digital Health

## Mission
Build beautiful healthcare apps fast — use the Flutter™ SDK and follow the HL7® FHIR® standard.

> FHIR® is the registered trademark of HL7 and is used with the permission of HL7. Use of the FHIR trademark does not constitute endorsement of this product by HL7.

## Features
* **A ready-made Widget to fill FHIR® Questionnaires.**
* Formatted and localized output of clinical observations
* Formatted and localized output of dates / times
* Localized output of clinical codings
* Development tree view to introspect clinical and administrative data structures
  
## Gallery
### Filler for FHIR Questionnaires
![Swift walk-through](https://user-images.githubusercontent.com/16414047/113286611-bdd93d00-92ec-11eb-9c7d-fd72dd0b99fe.gif)

**Click link below for extended, narrated video**

[Demo Video on YT](https://youtu.be/k9vEy9Z_L18)

### Display formatted, localized observations
![Screenshot](https://user-images.githubusercontent.com/16414047/112978818-12977f00-9158-11eb-8e1c-6772dcc3270a.png)


### Development overview
[Development Overview](doc/overview.md) - Learn how to use the Faidashu FHIRDash library in your own projects.

### Related projects
[![Pub Version](https://img.shields.io/pub/v/fhir?label=pub.dev&labelColor=333940&logo=dart)](https://pub.dev/packages/fhir)
This is mainly a user interface add-on to the awesome FHIRFLI "fhir" library: https://pub.dev/packages/fhir

### Contributing
Contributions and discussions are welcome! This is currently not well-defined yet. I am posting an invite link to the awesome FHIR-FLI
Slack channel which is run by some like-minded folks and where I can be frequently found:


[![FHIR-FLI Slack Channel](doc/images/Slack_RGB-98x40-335cb2d.png)](https://join.slack.com/t/fhir-fli/shared_invite/zt-ofv2cycm-9yjdMj8a~zXp7nDBeB_sNQ)  
[Join the FHIR-FLI Slack channel!](https://join.slack.com/t/fhir-fli/shared_invite/zt-ofv2cycm-9yjdMj8a~zXp7nDBeB_sNQ)

### License
The library is licensed under the MIT license. The full license text is here [LICENSE](LICENSE).

### Full list of legal attributions
Due to its nature, this library requires a multitude of third-party content and licenses. It is up to you to examine the
provided information and decide whether you meet the obligations to use this library and/or the contained content.

[Legal Information](doc/disclaimers.md)

---------------------------------------

**This information is not a substitute for professional legal advice.**

---------------------------------------
